import { HttpError } from '../errors.mjs';
import { DEFAULT_TRANSFORM_RESULT_FN } from '../transform-result.mjs';
import { toResponseResponsePayload, toMultiPartResponsePayload, toPushResponsePayload } from '../to-response-payload.mjs';
/** @deprecated */
export async function sendResponseResult(responseResult, rawResponse, transformResult = DEFAULT_TRANSFORM_RESULT_FN) {
    /**
     * TypeScript complains because of function call signature mismatches.
     * The signatures, however, are identical, thus we cas this here to suppress warnings,
     */
    const response = rawResponse;
    const responsePayload = toResponseResponsePayload(responseResult, transformResult);
    for (const [name, value] of Object.entries(responsePayload.headers)) {
        response.setHeader(name, value);
    }
    response.statusCode = responsePayload.status;
    response.on("close", () => {
        responsePayload.source.return();
    });
    for await (const value of responsePayload.source) {
        response.write(value);
    }
    response.end();
}
/** @deprecated */
export async function sendMultipartResponseResult(multipartResult, rawResponse, transformResult = DEFAULT_TRANSFORM_RESULT_FN) {
    /**
     * TypeScript complains because of function call signature mismatches.
     * The signatures, however, are identical, thus we cas this here to suppress warnings,
     */
    const response = rawResponse;
    const responsePayload = toMultiPartResponsePayload(multipartResult, transformResult);
    for (const [name, value] of Object.entries(responsePayload.headers)) {
        response.setHeader(name, value);
    }
    response.statusCode = responsePayload.status;
    response.on("close", () => {
        responsePayload.source.return();
    });
    for await (const value of responsePayload.source) {
        response.write(value);
    }
    response.end();
}
/** @deprecated */
export async function sendPushResult(pushResult, rawResponse, transformResult = DEFAULT_TRANSFORM_RESULT_FN) {
    /**
     * TypeScript complains because of function call signature mismatches.
     * The signatures, however, are identical, thus we cas this here to suppress warnings,
     */
    const response = rawResponse;
    const responsePayload = toPushResponsePayload(pushResult, transformResult);
    for (const [name, value] of Object.entries(responsePayload.headers)) {
        response.setHeader(name, value);
    }
    response.statusCode = responsePayload.status;
    response.on("close", () => {
        responsePayload.source.return();
    });
    for await (const value of responsePayload.source) {
        response.write(value);
    }
    response.end();
}
/** @deprecated */
export async function sendResult(result, rawResponse, transformResult = DEFAULT_TRANSFORM_RESULT_FN) {
    switch (result.type) {
        case "RESPONSE":
            return sendResponseResult(result, rawResponse, transformResult);
        case "MULTIPART_RESPONSE":
            return sendMultipartResponseResult(result, rawResponse, transformResult);
        case "PUSH":
            return sendPushResult(result, rawResponse, transformResult);
        default:
            throw new HttpError(500, "Cannot process result.");
    }
}
