/**
 * Chain AsyncIterable in sequence.
 */
export function asyncIterableChain(...subjects) {
    const iterators = subjects.map((subject) => subject[Symbol.asyncIterator]());
    return {
        [Symbol.asyncIterator]() {
            return this;
        },
        async next() {
            if (iterators.length === 0) {
                return Promise.resolve({ value: undefined, done: true });
            }
            const iterator = iterators[0];
            const value = await iterator.next();
            if (value.done === true) {
                if (iterator === iterators[0]) {
                    iterators.shift();
                }
                return this.next();
            }
            return value;
        },
        throw(err) {
            throw err;
        },
        return() {
            iterators.forEach((iterator) => { var _a; return (_a = iterator.return) === null || _a === void 0 ? void 0 : _a.call(iterator); });
            return Promise.resolve({ value: undefined, done: true });
        },
    };
}
