"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toReadable = void 0;
const stream_1 = require("stream");
/**
 * Transform an AsyncGenerator to a Readable.
 *
 * This helper is useful especially for fastify as the Reply.send method has support for consuming streams,
 * but not async iterable sources.
 */
function toReadable(source) {
    const readable = new stream_1.Readable({
        encoding: "utf-8",
    });
    readable._destroy = async (error, callback) => {
        try {
            await (error != null ? source.throw(error) : source.return());
        }
        catch (error) {
            return callback(error);
        }
        callback(error);
    };
    let running = false;
    readable._read = async (size) => {
        if (running) {
            return;
        }
        running = true;
        try {
            let cursor;
            do {
                cursor = await source.next(size);
                if (cursor.done) {
                    return readable.push(null);
                }
                readable.push(cursor.value);
            } while (cursor.done === false);
        }
        catch (error) {
            process.nextTick(readable.emit.bind(readable, "error", error));
        }
        finally {
            running = false;
        }
        return undefined;
    };
    return readable;
}
exports.toReadable = toReadable;
