"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toResponsePayload = exports.toPushResponsePayload = exports.toMultiPartResponsePayload = exports.toResponseResponsePayload = void 0;
const errors_1 = require("./errors");
const async_generator_of_1 = require("./util/async-generator-of");
const calculate_byte_length_1 = require("./util/calculate-byte-length");
const async_iterable_map_1 = require("./util/async-iterable-map");
const async_iterable_chain_1 = require("./util/async-iterable-chain");
const transform_result_1 = require("./transform-result");
const async_iterable_final_value_from_error_1 = require("./util/async-iterable-final-value-from-error");
const graphql_1 = require("graphql");
function toResponseResponsePayload(result, transformResult = transform_result_1.DEFAULT_TRANSFORM_RESULT_FN) {
    const data = JSON.stringify(transformResult(result.payload));
    return {
        headers: {
            ...Object.fromEntries(result.headers.map(({ name, value }) => [name, value])),
            "content-type": "application/json",
            "content-length": String((0, calculate_byte_length_1.calculateByteLength)(data)),
        },
        source: (0, async_generator_of_1.asyncGeneratorOf)(data),
        status: result.status,
    };
}
exports.toResponseResponsePayload = toResponseResponsePayload;
function toMultiPartResponsePayload(result, transformResult = transform_result_1.DEFAULT_TRANSFORM_RESULT_FN) {
    return {
        headers: {
            // prettier-ignore
            "Connection": "keep-alive",
            "Content-Type": 'multipart/mixed; boundary="-"',
            "Transfer-Encoding": "chunked",
        },
        source: (0, async_iterable_chain_1.asyncIterableChain)((0, async_generator_of_1.asyncGeneratorOf)("---"), (0, async_iterable_map_1.asyncIterableMap)(result, (value) => {
            const chunk = JSON.stringify(transformResult(value));
            const data = [
                "",
                "Content-Type: application/json; charset=utf-8",
                "Content-Length: " + (0, calculate_byte_length_1.calculateByteLength)(chunk),
                "",
                chunk,
            ];
            if (value.hasNext) {
                data.push("---");
            }
            return data.join("\r\n");
        }), (0, async_generator_of_1.asyncGeneratorOf)("\r\n-----\r\n")),
        status: 200,
    };
}
exports.toMultiPartResponsePayload = toMultiPartResponsePayload;
function toPushResponsePayload(result, transformResult = transform_result_1.DEFAULT_TRANSFORM_RESULT_FN) {
    return {
        headers: {
            "Content-Type": "text/event-stream",
            // prettier-ignore
            "Connection": "keep-alive",
            "Cache-Control": "no-cache",
        },
        source: (0, async_iterable_final_value_from_error_1.asyncIterableFinalValueFromError)((0, async_iterable_map_1.asyncIterableMap)(result, (value) => `data: ${JSON.stringify(transformResult(value))}\n\n`), (err) => {
            var _a, _b;
            return `data: ` +
                JSON.stringify(transformResult({
                    errors: [new graphql_1.GraphQLError((_b = (_a = err) === null || _a === void 0 ? void 0 : _a.message) !== null && _b !== void 0 ? _b : String(err))],
                })) +
                `\n\n`;
        }),
        status: 200,
    };
}
exports.toPushResponsePayload = toPushResponsePayload;
/**
 * Transforms the a `ProcessRequestResult` into a text stream published via an AsyncGenerator that can be piped into any HTTP framework.
 */
function toResponsePayload(result, transformResult = transform_result_1.DEFAULT_TRANSFORM_RESULT_FN) {
    switch (result.type) {
        case "RESPONSE":
            return toResponseResponsePayload(result, transformResult);
        case "MULTIPART_RESPONSE":
            return toMultiPartResponsePayload(result, transformResult);
        case "PUSH":
            return toPushResponsePayload(result, transformResult);
        default:
            throw new errors_1.HttpError(500, "Cannot process result.");
    }
}
exports.toResponsePayload = toResponsePayload;
